import React, { useContext } from 'react';
import { getFileExtension, getFileType, truncate } from '@gathertown/uikit-utils';
import Box from '../../components/Box';
import Icon from '../../components/Icon';
import PressBox from '../../components/PressBox';
import Text from '../../components/Text';
import createStyleSheet from '../../styles/createStyleSheet';
import useUIKitTheme from '../../theme/useUIKitTheme';
import MessageContainer from './MessageContainer';
import { CustomComponentContext } from '../../context/CustomComponentCtx';
const FileMessage = props => {
  const {
    variant = 'incoming',
    message,
    children
  } = props;
  const {
    colors
  } = useUIKitTheme();
  const ctx = useContext(CustomComponentContext);
  const fileType = getFileType(props.message.type || getFileExtension(props.message.name));
  const color = colors.ui.groupChannelMessage[variant];
  const icon = /*#__PURE__*/React.createElement(Icon.File, {
    fileType: fileType,
    size: 24,
    containerStyle: {
      backgroundColor: colors.background,
      padding: 2,
      borderRadius: 8,
      marginRight: 8
    }
  });
  return /*#__PURE__*/React.createElement(MessageContainer, props, /*#__PURE__*/React.createElement(PressBox, {
    onPress: props.onPress,
    onLongPress: props.onLongPress
  }, _ref => {
    var _props$strings, _props$strings2;
    let {
      pressed
    } = _ref;
    return ctx !== null && ctx !== void 0 && ctx.renderFileMessage ? ctx.renderFileMessage({
      message,
      pressed,
      fileType,
      fileName: ((_props$strings = props.strings) === null || _props$strings === void 0 ? void 0 : _props$strings.fileName) || props.message.name,
      children,
      defaultIcon: icon
    }) : /*#__PURE__*/React.createElement(Box, {
      backgroundColor: pressed ? color.pressed.background : color.enabled.background,
      style: styles.container
    }, /*#__PURE__*/React.createElement(Box, {
      style: styles.bubble
    }, icon, /*#__PURE__*/React.createElement(Text, {
      body3: true,
      ellipsizeMode: 'middle',
      numberOfLines: 1,
      color: pressed ? color.pressed.textMsg : color.enabled.textMsg,
      style: styles.name
    }, truncate(((_props$strings2 = props.strings) === null || _props$strings2 === void 0 ? void 0 : _props$strings2.fileName) || props.message.name, {
      mode: 'mid',
      maxLen: 20
    }))), props.children);
  }));
};
const styles = createStyleSheet({
  container: {
    overflow: 'hidden',
    borderRadius: 16
  },
  bubble: {
    flexDirection: 'row',
    alignItems: 'center',
    paddingHorizontal: 12,
    paddingVertical: 6
  },
  name: {
    flexShrink: 1
  }
});
export default FileMessage;
//# sourceMappingURL=Message.file.js.map